@@ -27,7 +27,7 @@ module Fog
           data = service.insert_forwarding_rule(identity, region, attributes)
           operation = Fog::Compute::Google::Operations.new(:service => service)
                                                       .get(data.name, nil, data.region)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
           reload
         end
 
