@@ -13,7 +13,7 @@ module Fog
         def add_target_pool_health_checks(target_pool, region, health_checks)
           check_list = health_checks.map do |health_check|
             ::Google::Apis::ComputeV1::HealthCheckReference.new(
-              :health_check => health_check
+              health_check: health_check
             )
           end
 
@@ -22,7 +22,7 @@ module Fog
             region.split("/")[-1],
             target_pool,
             ::Google::Apis::ComputeV1::AddTargetPoolsHealthCheckRequest.new(
-              :health_checks => check_list
+              health_checks: check_list
             )
           )
         end
