@@ -3,7 +3,9 @@ module Fog
     class Google
       class Mock
         def delete_zone_operation(_zone, _operation)
+          # :no-coverage:
           Fog::Mock.not_implemented
+          # :no-coverage:
         end
       end
 
@@ -12,14 +14,7 @@ module Fog
 
         def delete_zone_operation(zone_name, operation)
           zone_name = zone_name.split("/")[-1] if zone_name.start_with? "http"
-          api_method = @compute.zone_operations.delete
-          parameters = {
-            "project" => @project,
-            "zone" => zone_name,
-            "operation" => operation
-          }
-
-          request(api_method, parameters)
+          @compute.delete_zone_operation(@project, zone_name, operation)
         end
       end
     end
