@@ -16,10 +16,10 @@ module Fog
                            order_by: nil, page_token: nil)
           @compute.list_addresses(
             @project, region_name,
-            :filter => filter,
-            :max_results => max_results,
-            :order_by => order_by,
-            :page_token => page_token
+            filter: filter,
+            max_results: max_results,
+            order_by: order_by,
+            page_token: page_token
           )
         end
       end
