@@ -12,13 +12,13 @@ module Fog
       class Real
         # List address resources in the specified project
         # @see https://cloud.google.com/compute/docs/reference/latest/globalAddresses
-        def list_global_addresses(filter: nil, max_results: nil, order_by: nil,
+          def list_global_addresses(filter: nil, max_results: nil, order_by: nil,
                                   page_token: nil)
           @compute.list_global_addresses(@project,
-                                         :filter => filter,
-                                         :max_results => max_results,
-                                         :order_by => order_by,
-                                         :page_token => page_token)
+                                         filter: filter,
+                                         max_results: max_results,
+                                         order_by: order_by,
+                                         page_token: page_token)
         end
       end
     end
