@@ -14,8 +14,8 @@ module Fog
                                          order_by: nil, page_token: nil)
           @compute.list_global_forwarding_rules(
             @project,
-            :filter => filter, :max_results => max_results,
-            :order_by => order_by, :page_token => page_token
+            filter: filter, max_results: max_results,
+            order_by: order_by, page_token: page_token
           )
         end
       end
