@@ -14,10 +14,10 @@ module Fog
                                page_token: nil, order_by: nil)
           zone = zone.split("/")[-1] if zone.start_with? "http"
           @compute.list_machine_types(@project, zone,
-                                      :filter => filter,
-                                      :max_results => max_results,
-                                      :page_token => page_token,
-                                      :order_by => order_by)
+                                      filter: filter,
+                                      max_results: max_results,
+                                      page_token: page_token,
+                                      order_by: order_by)
         end
       end
     end
