@@ -14,10 +14,10 @@ module Fog
                               order_by: nil, page_token: nil)
           @compute.list_target_pools(
             @project, region.split("/")[-1],
-            :filter => filter,
-            :max_results => max_results,
-            :order_by => order_by,
-            :page_token => page_token
+            filter: filter,
+            max_results: max_results,
+            order_by: order_by,
+            page_token: page_token
           )
         end
       end
