@@ -19,7 +19,11 @@ module Fog
 
         def host_path_query(params, expires)
           params[:headers]["Date"] = expires.to_i
-          params[:path] = URI.encode(params[:path]).gsub("%2F", "/")
+          # implementation from CGI.escape, but without ' ' to  '+' conversion
+          params[:path] = params[:path].b.gsub(/([^a-zA-Z0-9_.\-~]+)/) { |m|
+            '%' + m.unpack('H2' * m.bytesize).join('%').upcase
+          }.gsub("%2F", "/")
+
           query = []
 
           if params[:query]
