@@ -66,14 +66,14 @@ module Fog
           nil
         end
 
-        def get_http_url(key, expires)
+        def get_http_url(key, expires, options = {})
           requires :directory
-          service.get_object_http_url(directory.key, key, expires)
+          service.get_object_http_url(directory.key, key, expires, options)
         end
 
-        def get_https_url(key, expires)
+        def get_https_url(key, expires, options = {})
           requires :directory
-          service.get_object_https_url(directory.key, key, expires)
+          service.get_object_https_url(directory.key, key, expires, options)
         end
 
         def head(key, options = {})
