@@ -2,15 +2,15 @@ module Fog
   module Storage
     class GoogleXML
       module GetObjectHttpsUrl
-        def get_object_https_url(bucket_name, object_name, expires)
+        def get_object_https_url(bucket_name, object_name, expires, options = {})
           raise ArgumentError.new("bucket_name is required") unless bucket_name
           raise ArgumentError.new("object_name is required") unless object_name
-          https_url({
-                      :headers  => {},
-                      :host     => @host,
-                      :method   => "GET",
-                      :path     => "#{bucket_name}/#{object_name}"
-                    }, expires)
+
+          https_url(options.merge(:headers  => {},
+                                  :host     => @host,
+                                  :method   => "GET",
+                                  :path     => "#{bucket_name}/#{object_name}"),
+                    expires)
         end
       end
 
@@ -25,9 +25,6 @@ module Fog
         # ==== Returns
         # * response<~Excon::Response>:
         #   * body<~String> - url for object
-        #
-        # ==== See Also
-        # http://docs.amazonwebservices.com/AmazonS3/latest/dev/S3_QSAuth.html
 
         include GetObjectHttpsUrl
       end
