@@ -1,5 +1,6 @@
 require "helpers/test_helper"
 require "helpers/test_collection"
+require "retriable"
 
 # Use :test credentials in ~/.fog for live integration testing
 # XXX not sure if this will work on Travis CI or not
@@ -22,7 +23,7 @@ TEST_IMAGE_FAMILY = "debian-9".freeze
 
 # XXX This depends on a public image in gs://fog-test-bucket; there may be a better way to do this
 # The image was created like so: https://cloud.google.com/compute/docs/images#export_an_image_to_google_cloud_storage
-TEST_RAW_DISK_SOURCE = "http://storage.googleapis.com/fog-test-bucket/fog-test-raw-disk-source.image.tar.gz".freeze
+TEST_RAW_DISK_SOURCE = "https://storage.googleapis.com/fog-testing-bucket/fog-test-raw-disk-source.image.tar.gz".freeze
 
 TEST_SQL_TIER = "db-n1-standard-1".freeze
 TEST_SQL_REGION = TEST_REGION
@@ -87,8 +88,21 @@ wLjafhPTSAIS0jijglJ7uzaSbFUW11fw1/EIqIFNe0R0Xf9lsyPxFA==
 -----END RSA PRIVATE KEY-----
 KEY
 
+# Retry module config - standard retriable gem settings
+# see: https://github.com/kamui/retriable
+RETRIABLE_TRIES = 3
+RETRIABLE_BASE_INTERVAL = 50
+
 class FogIntegrationTest < MiniTest::Test
   def namespaced_name
     "#{self.class}_#{name}"
   end
+
+  def retry_on(klass)
+    Retriable.retriable(on: klass,
+                        tries: RETRIABLE_TRIES,
+                        base_interval: RETRIABLE_BASE_INTERVAL) do
+      yield
+    end
+  end
 end
